@@ -42,7 +42,7 @@ pub struct StaticVec<T, const N: usize> {
   length: usize,
 }
 
-impl<T, const N: usize> StaticVec<T, {N}> {
+impl<T, const N: usize> StaticVec<T, { N }> {
   ///Returns a new StaticVec instance.
   #[inline(always)]
   pub fn new() -> Self {
@@ -121,8 +121,6 @@ impl<T, const N: usize> StaticVec<T, {N}> {
   ///
   ///Example usage:
   ///```
-  ///use staticvec::*;
-  ///
   ///fn main() {
   ///  let mut i = 0;
   ///  let v = StaticVec::<i32, 64>::filled_with(|| { i += 1; i });
@@ -151,7 +149,7 @@ impl<T, const N: usize> StaticVec<T, {N}> {
   ///have been added to it with `push`, `insert`, etc. except in the case
   ///that it has been set directly with the unsafe `set_len` function.
   #[inline(always)]
-  pub fn len(&self) -> usize {
+  pub const fn len(&self) -> usize {
     self.length
   }
 
@@ -163,6 +161,12 @@ impl<T, const N: usize> StaticVec<T, {N}> {
     N
   }
 
+  /// Returns the remaining capacity of the `StaticVec`.
+  #[inline(always)]
+  pub const fn remaining_capacity(&self) -> usize {
+    self.capacity() - self.len()
+  }
+
   ///Directly sets the `length` field of the StaticVec to `new_len`. Useful if you intend
   ///to write to it solely element-wise, but marked unsafe due to how it creates
   ///the potential for reading from unitialized memory later on.
@@ -173,25 +177,25 @@ impl<T, const N: usize> StaticVec<T, {N}> {
 
   ///Returns true if the current length of the StaticVec is 0.
   #[inline(always)]
-  pub fn is_empty(&self) -> bool {
+  pub const fn is_empty(&self) -> bool {
     self.length == 0
   }
 
   ///Returns true if the current length of the StaticVec is greater than 0.
   #[inline(always)]
-  pub fn is_not_empty(&self) -> bool {
+  pub const fn is_not_empty(&self) -> bool {
     self.length > 0
   }
 
   ///Returns true if the current length of the StaticVec is equal to its capacity.
   #[inline(always)]
-  pub fn is_full(&self) -> bool {
+  pub const fn is_full(&self) -> bool {
     self.length == N
   }
 
   ///Returns true if the current length of the StaticVec is less than its capacity.
   #[inline(always)]
-  pub fn is_not_full(&self) -> bool {
+  pub const fn is_not_full(&self) -> bool {
     self.length < N
   }
 
@@ -483,6 +487,20 @@ impl<T, const N: usize> StaticVec<T, {N}> {
     self.length += added_length;
   }
 
+  ///Copies and appends all elements, if any, of a slice to the StaticVec if the
+  ///StaticVec's remaining capacity is greater than the length of the slice, or returns
+  ///an error indicating that's not the case otherwise.
+  #[inline(always)]
+  pub fn try_extend_from_slice(&mut self, other: &[T]) -> Result<(), &'static str>
+  where T: Copy {
+    if self.remaining_capacity() < other.len() {
+      Err("No space left!")
+    } else {
+      self.extend_from_slice(other);
+      Ok(())
+    }
+  }
+
   ///Removes the specified range of elements from the StaticVec and returns them in a new one.
   #[inline]
   pub fn drain<R>(&mut self, range: R) -> Self
